<?php
/**
 * Program Five Widget
*/

namespace Elementor;
class Falar_Program_Five extends Widget_Base {

	public function get_name() {
        return 'Program_Five';
    }

	public function get_title() {
        return __( 'Program Five', 'falar-toolkit' );
    }

	public function get_icon() {
        return 'eicon-person';
    }

	public function get_categories() {
        return [ 'falar-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'program_section',
			[
				'label' => __( 'Program Five', 'falar-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'cat_name',
                [
                    'label' => __( 'Choose Category', 'falar-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => falar_toolkit_get_page_program_cat_el(),
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => __( 'Program Order By', 'falar-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => __( 'DESC', 'falar-toolkit' ),
                        'ASC'       => __( 'ASC', 'falar-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => __( 'Post Per Page', 'falar-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 14,
                    'description' => __('If you want to see all post, type -1','falar-toolkit')
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'program_style',
			[
				'label' => __( 'Style', 'falar-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => __( 'Title Color', 'falar-toolkit' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-history-title h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'label'    => __( 'Title Typography', 'falar-toolkit' ),
                'selector' => '{{WRAPPER}} .about-history-title h2',
            ]
        );
        $this->add_control(
            'content_color',
            [
                'label'     => __( 'Content Color', 'falar-toolkit' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .about-history-content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'content_typography',
                'label'    => __( 'Content Typography', 'falar-toolkit' ),
                'selector' => '{{WRAPPER}} .about-history-content p',
            ]
        );
        $this->add_control(
            'card_title_color',
            [
                'label'     => __( 'Card Title Color', 'falar-toolkit' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .program-list .item' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'card_title_typography',
                'label'    => __( 'Card Title Typography', 'falar-toolkit' ),
                'selector' => '{{WRAPPER}} .program-list .item',
            ]
        );
        
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Program Query
        if( $settings['cat_name'] != '' ) {
            $args = array(
                'post_type'     => 'program',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'program_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat_name'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'program',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }

        $program_array = new \WP_Query( $args );

        ?>
        <!-- Program Link Warp Start -->
        <div class="graduate-faculty-warp pb-100">
            <div class="container">
                <div class="row">
                    <?php
                        $i=1;
                        while($program_array->have_posts()):
                        $program_array->the_post();
                        $id                =  get_the_ID();
                    ?>
                    <div class="col-lg-6">
                        <div class="faculty-list">
                            <a href="<?php echo esc_url(get_the_permalink($id)); ?>" class="item <?php if($i == 1): ?>top<?php endif; ?> <?php if($i == 2): ?>top<?php endif; ?>"><?php the_title(); ?>
                                <i class="ti ti-caret-right-filled"></i>
                            </a>
                        </div>
                    </div>
                    <?php $i++; endwhile; wp_reset_postdata();?>
                </div>
            </div>
        </div>
        <!-- Program Link Warp End -->
        <?php
	}

}

Plugin::instance()->widgets_manager->register( new Falar_Program_Five );